#!/bin/sh
#   Copyright (c) 2010 digitalSTROM.org, Zurich, Switzerland
#
#   Author: Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
#
#   This file is part of digitalSTROM Server.
#
#   netinfo.sh is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   netinfo.sh is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this file. If not, see <http://www.gnu.org/licenses/>.

# source common functions
. ./errlib.sh
. ./jsonlib.sh

LOGDIR="/var/log/dss11-websetup"
mkdir -p $LOGDIR 1>&2 >/dev/null
LAST_UPDATE_CODE="$LOGDIR/last-update-code.txt"
LAST_UPDATE_MESSAGE="$LOGDIR/last-update-msg.txt"

if [[ "$1" == "addon" ]]; then
LAST_UPDATE_CODE="$LOGDIR/last-update-code-addon.txt"
LAST_UPDATE_MESSAGE="$LOGDIR/last-update-msg-addon.txt"
elif [[ "$1" == "dsmfwupgrade" ]]; then
LAST_UPDATE_CODE="$LOGDIR/last-update-code-dsmfw.txt"
LAST_UPDATE_MESSAGE="$LOGDIR/last-update-msg-dsmfw.txt"
fi
echo "Content-Type: application/json"
echo ""

if [[ -e /var/lock/systemupdate ]]; then
    json_status $ERR_DOWAIT "Upate in progress, please wait..."
    exit 0
fi

if [[ -e /var/lock/rebootafterupdate ]]; then
    if [[ -n "$2" ]]; then
        json_status $ERR_NEED_REBOOT "The system needs to be rebooted"
        exit 0
    fi
fi

if [[ "$1" == "active" ]]; then
    json_ok
    exit 0
fi

if [[ -e $LAST_UPDATE_CODE ]]; then
    CODE=`cat $LAST_UPDATE_CODE | cut -d ':' -f 1`
    if [[ -z "$CODE" ]]; then
        echo $ERR_OK > $LAST_UPDATE_CODE
        json_ok
        exit 0
    fi

    SUBCODE=`cat $LAST_UPDATE_CODE | cut -d ':' -f 2`
    MESSAGE="Update failed"
    if [[ -e $LAST_UPDATE_MESSAGE ]]; then
        MSG="`cat $LAST_UPDATE_MESSAGE`"
        if [[ -n "$MSG" ]]; then
            MESSAGE="$MSG"
        fi
    fi

    if [[ "$1" == "dsmfwupgrade" ]]; then
        if [[ "$CODE" -eq "$ERR_OK" ]]; then
            if [[ -n "$SUBCODE" ]]; then
                echo "{ \"success\": true, \"code\": $CODE, \"updatecode\": $SUBCODE, \"message\": \"$MESSAGE\" }"
                exit 0
            fi
        fi
    fi

    if [[ "$CODE" -ne "$ERR_OK" ]]; then
        # parse subcode opkg return code or dsm firmware upgrade code
        if [[ "$CODE" -eq "$ERR_OPKG" ]] || [[ "$CODE" -eq "$ERR_UPDATE" ]]; then
            if [[ -z "$SUBCODE" ]]; then
                json_error $CODE "$MESSAGE"
            else
                json_error_update $CODE $SUBCODE "$MESSAGE"
            fi
        else
            json_error $CODE "$MESSAGE"
        fi
        exit 0
    fi
else
    echo $ERR_OK > $LAST_UPDATE_CODE
fi

json_ok
exit 0

